==> deepin-image-viewer_5.7.4.orig.tar.xz: deepin-image-viewer-5.7.4/src/translations/deepin-image-viewer_ast.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ast">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imáxenes</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Esti ficheru contién munches páxines, usa Evince pa veles toes.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">Abrir direutoriu</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nun tienes permisu pa ver la imaxe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Encaboxar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Desaniciar</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Triba</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificación</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamañu de ficheru</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mou d&apos;esposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;esposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempu d&apos;esposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flax</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llonxitú focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máx.</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mou de midición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flax</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelu de lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaciu de colores</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modélu de cámara</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Axustar páxina a la imaxe</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Axustar imaxe a la páxina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escalar a:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetros</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetros</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Pulgaes</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escaláu</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Switcher</source>
        <translation type="vanished">Conmutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="vanished">Eslizante</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation type="vanished">Aniellu</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Esbillar direutoriu</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Esti direutoriu tien desactivao&apos;l sincronizar</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Amestar carpeta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Xestión de direutorios de sincronización</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>El llistáu de direutorios ta baleru</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Encaboxar sincronización</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imáxenes</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Estráxose&apos;l preséu</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Esti direutoriu yá nun esiste</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculando...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visión d&apos;imáxenes</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Finar presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla previa</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla siguiente</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atayos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Desaniciar</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Colar de pantalla completa</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="vanished">Introduz un atayu nuevu, por favor</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">Atayos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="vanished">Ver semeya</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">Álbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="vanished">Reafitar valores</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="vanished">Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Diapositiva</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="obsolete">Finar presentación</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="vanished">Imprentar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">Non favorita</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="vanished">Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">Álbum nuevu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Renomar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Desaniciar</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Switch effect</source>
        <translation type="vanished">Camudar efeutu</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">Duración</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="vanished">Camudar duración</translation>
    </message>
    <message>
        <source>second</source>
        <translation type="vanished">segundu</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished">Lo favorito de mio</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Siguiente</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished">Tamañu 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished">Axustar a la ventana</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Voltiar a drecha</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Desaniciar</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Xestión d&apos;imáxenes</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Lo favorito de mio</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamañu 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Axustar a la ventana</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished">Non favorita</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Favorita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Desaniciar</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nun s&apos;alcontraron imáxenes</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Effect</source>
        <translation type="vanished">Efeutu</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">Duración</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">Atayos</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Ver</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">Álbum</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="vanished">Álbum nuevu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Axustes</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Llinia temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Amestar al álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Amestar al álbum nuevu</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Colar de pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">Diapositiva</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Amosar ventana de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Anubrir ventana de navegación</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Desaniciar</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Toles imáxenes</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_ast.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ast">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visión d&apos;imáxenes</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Colar de pantalla completa</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atayos</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation></translation>
    </message>
</context>
</TS>
